@@ -1,3 +1,5 @@
+from slugify import slugify
+
 from .RuckusSSH import RuckusSSH
 
 
@@ -13,16 +15,21 @@ class Ruckus:
         self.timeout = timeout
 
         self.ssh = None
-        self.connect()
 
     def __del__(self) -> None:
         """Disconnect on delete."""
         self.disconnect()
 
-    def connect(self) -> None:
+    @staticmethod
+    async def create(host: str, username: str, password: str, login_timeout=15, timeout=10):
+        ruckus = Ruckus(host, username, password, login_timeout=login_timeout, timeout=timeout)
+        await ruckus.connect()
+        return ruckus
+
+    async def connect(self) -> None:
         """Create SSH connection and login."""
         ssh = RuckusSSH(encoding="utf-8")
-        ssh.login(self.host, username=self.username, password=self.password, login_timeout=self.login_timeout)
+        await ssh.login(self.host, username=self.username, password=self.password, login_timeout=self.login_timeout)
         self.ssh = ssh
 
     def disconnect(self) -> None:
@@ -30,25 +37,6 @@ class Ruckus:
         if self.ssh and self.ssh.isalive():
             self.ssh.close()
 
-    def clients(self) -> dict:
-        """Pull active clients from the device."""
-        if not self.ssh.isalive():
-            self.connect()
-
-        result = self.ssh.run_privileged("show current-active-clients all")
-        result, _, _ = result.partition("Last 300 Events/Activities:")
-
-        result = self.__parse_kv(result)
-
-        return {e['Mac Address']: e for e in result['Current Active Clients']['Clients']}
-
-    def mesh_name(self) -> str:
-        """Pull the current mesh name."""
-        try:
-            return self.mesh_info()['Mesh Settings']['Mesh Name(ESSID)']
-        except KeyError:
-            return 'Ruckus Mesh'
-
     @staticmethod
     def __parse_kv(response) -> dict:
         """Parse Ruckus nested key-value output into a dict."""
@@ -76,7 +64,7 @@ class Ruckus:
 
             if is_header:
                 # Remove colon, then strip whitespace
-                line = line[:-1].strip()
+                line = slugify(line[:-1], separator="_")
                 parent_node = breadcrumbs[-1]
                 node = {}
 
@@ -92,35 +80,55 @@ class Ruckus:
 
                 breadcrumbs.append(node)
             else:
-                key, _, value = line.partition("= ")
+                key, _, value = line.partition("=")
+                key = slugify(key, separator="_")
+                value = value.strip()
                 if key:
-                    node[key.strip()] = value.strip()
+                    node[key] = value
 
         return root
 
-    def mesh_info(self) -> dict:
+    async def mesh_info(self) -> dict:
         """Pull the current mesh name."""
         if not self.ssh.isalive():
-            self.connect()
+            await self.connect()
 
-        result = self.ssh.run_privileged("show mesh info")
+        result = await self.ssh.run_privileged("show mesh info")
 
         return self.__parse_kv(result)
 
-    def system_info(self) -> dict:
+    async def mesh_name(self) -> str:
+        """Pull the current mesh name."""
+        try:
+            mesh_info = await self.mesh_info()
+            return mesh_info['mesh_settings']['mesh_name_essid']
+        except KeyError:
+            return 'Ruckus Mesh'
+
+    async def system_info(self) -> dict:
         """Pull the system info."""
         if not self.ssh.isalive():
-            self.connect()
+            await self.connect()
 
-        result = self.ssh.run_privileged("show sysinfo")
+        result = await self.ssh.run_privileged("show sysinfo")
 
         return self.__parse_kv(result)
 
-    def ap_info(self) -> dict:
+    async def current_active_clients(self) -> dict:
+        """Pull active clients from the device."""
+        if not self.ssh.isalive():
+            await self.connect()
+
+        result = await self.ssh.run_privileged("show current-active-clients all")
+        result, _, _ = result.partition("Last 300 Events/Activities:")
+
+        return self.__parse_kv(result)
+
+    async def ap_info(self) -> dict:
         """Pull info about current access points."""
         if not self.ssh.isalive():
-            self.connect()
+            await self.connect()
 
-        result = self.ssh.run_privileged("show ap all")
+        result = await self.ssh.run_privileged("show ap all")
 
         return self.__parse_kv(result)
